@@ -4,6 +4,7 @@ from typing import Type
 from pydantic import BaseModel
 from starlette.responses import Response
 
+from pymultirole_plugins.v1 import ABCSingleton
 from pymultirole_plugins.v1.schema import Document
 
 
@@ -11,7 +12,7 @@ class FormatterParameters(BaseModel):
     pass
 
 
-class FormatterBase(metaclass=abc.ABCMeta):
+class FormatterBase(metaclass=ABCSingleton):
     """Base class for example plugin used in the tutorial.
     """
 
